sqltriples.Types

Package sqltriples :: Module Types |
[show private | hide private]
[frames | no frames]

## Module sqltriples.Types

Special data types inheriting from the unicode type in order to provide interoperability with rdflib.

Copyright (C) 2006 Paul Boddie <paul@boddie.org.uk>

This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

Classes
`AbstractExpression` |
`BNode` | A BNode compatible with the rdflib class of the same name.
`Defined` | A class indicating a value defined for a particular relation.
`Expression` |
`Literal` | A literal compatible with the rdflib class of the same name.
`Namespace` | A namespace compatible with the rdflib class of the same name.
`Pattern` |
`Special` |
`URIRef` | An URI reference compatible with the rdflib class of the same name.

Variable Summary
`tuple` | `ALL` = `(None, None, None)`
`Namespace` | `RDFNS` = `Namespace: http://www.w3.org/1999/02/22-rdf-synt...`
`Namespace` | `TYPE` = `Namespace: http://www.w3.org/1999/02/22-rdf-synta...`

Variable Details

    ### ALL Type: `tuple` Value:
        (None, None, None)

    ### RDFNS Type: `Namespace` Value:
        Namespace: http://www.w3.org/1999/02/22-rdf-syntax-ns#

    ### TYPE Type: `Namespace` Value:
        Namespace: http://www.w3.org/1999/02/22-rdf-syntax-ns#type

Generated by Epydoc 2.1 on Sat Sep 30 00:54:36 2006 | http://epydoc.sf.net